==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ms/general.php <==
<?php

    return [
    'accessories'			=> 'Aksesori',
    'activated'			    => 'Diaktifkan',
    'accessory'				=> 'Aksesori',
    'accessory_report'		=> 'Laporan Aksesori',
    'action'                => 'Tindakan',
    'activity_report'		=> 'Laporan Aktiviti',
    'address'				=> 'Alamat',
    'admin'					=> 'Pentadbir',
    'administrator'			=> 'Pentadbir',
    'add_seats'             => 'Menambah kerusi',
    'all_assets'			=> 'Semua Harta',
    'all'       			=> 'Semua',
    'archived'              => 'Diarkibkan',
    'asset_models'			=> 'Model Harta',
    'asset_model'			=> 'Model',
    'asset'					=> 'Harta',
    'asset_report'          => 'Laporan Harta',
    'asset_tag'				=> 'Tag Harta',
    'assets_available'		=> 'Harta yang ada',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Log Audit',
    'assets'				=> 'Harta',
    'avatar_delete'         => 'Hapuskan Avatar',
    'avatar_upload'         => 'Muat naik Avatar',
    'back'      			=> 'Belakang',
    'bad_data'      		=> 'Tiada apa-apa Dijumpai. Mungkin data buruk?',
    'bulkaudit'             => 'Audit Bulk',
    'bulkaudit_status'      => 'Status Audit',
    'bulk_checkout'  		=> 'Checkout Pukal',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Batalkan',
    'categories'			=> 'Kategori',
    'category'				=> 'Kategori',
    'change' 		        => 'Dalam keluar',
    'changeemail'  			=> 'Ubah Alamat E-mail',
    'changepassword'  		=> 'Tukar kata laluan',
    'checkin'  				=> 'Terima',
    'checkin_from'  		=> 'Semak dari',
    'checkout'  			=> 'Agihkan',
    'checkouts_count'       => 'Semak Keluar',
    'checkins_count'        => 'Semak masuk',
    'user_requests_count'   => 'Permintaan',
    'city'  				=> 'Bandar',
	'click_here'			=> 'Tekan di sini',
    'clear_selection'		=> 'Buang pilihan',
    'companies'			    => 'Syarikat-syarikat',
    'company'				=> 'Syarikat',
    'component'			    => 'Komponen',
    'components'			=> 'Komponen',
	'complete'				=> 'Lengkap',
    'consumable'			=> 'Boleh makan',
    'consumables'			=> 'Makanan yang boleh dimakan',
    'country'  				=> 'Negara',
    'create'				=> 'Cipta Baru',
    'created'               => 'Perkara yang Dibuat',
    'created_asset'			=> 'cipta harta',
    'created_at' 			=> 'Cipta Pada',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Dikemaskini di',
    'currency'  			=> 'RM', // this is deprecated
    'current'  				=> 'Semasa',
    'custom_report'         => 'Laporan Harta Pilihan',
    'dashboard'				=> 'Papan Pemuka',
    'days'      			=> 'hari',
    'days_to_next_audit'    => 'Hari ke Audit Seterusnya',
    'date'					=> 'Tarikh',
    'debug_warning'         => 'Amaran!',
    'debug_warning_text'    => 'Aplikasi ini berjalan dalam mod pengeluaran dengan debug membolehkan. Ini boleh mendedahkan data sensitif jika aplikasi anda boleh diakses oleh dunia luar. Lumpuhkan mod debug dengan menetapkan <code>APP_DEBUG</code> nilai dalam fail <code>.env</code> anda ke <code>false</code>.',
    'delete'  				=> 'Hapuskan',
    'delete_confirm'  		=> 'Adakah anda pasti ingin memadamkan :item?',
    'deleted'  				=> 'Dihapuskan',
    'delete_seats'  		=> 'Kerusi dipadamkan',
    'departments'           => 'Jabatan',
    'department'           => 'Jabatan',
    'deployed'				=> 'Telah Diagihkan',
    'depreciation_report'	=> 'Laporan Susut nilai',
    'details'               => 'Terperinci',
    'download'				=> 'Muat turun',
    'download_all'				=> 'Download All',
    'depreciation'			=> 'Susut Nilai',
    'editprofile'  			=> 'Kemaskini Profail Anda',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Domain E-mel',
    'email_format'			=> 'Format E-mel',
    'email_domain_help'		=> 'Ini digunakan untuk menjana alamat e-mel semasa mengimport',
    'filastname_format'			=> 'Nama Akhir Permulaan Pertama (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nama Akhir Nama Pertama (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Nama Pertama Nama Akhir (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Pertama',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Nama pertama',
    'first_name_format'		=> 'Nama Pertama (jane@example.com)',
    'files'                 => 'Fail-fail',
    'file_name'				=> 'Fail',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Muat Naik Fail',
    'generate'				=> 'Laksanakan',
     'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Kumpulan',
    'gravatar_email'        => 'Alam e-mel gravatar',
    'history'  			    => 'Sejarah',
    'history_for'  			=> 'Sejarah untuk',
    'id'  					=> 'ID',
    'image'                 => 'Gambar',
    'image_delete'         	=> 'Hapuskan imej',
    'image_upload'         	=> 'Muat naik imej',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Sejarah Import',
    'asset_maintenance'        => 'Penyelenggaraan Aset',
    'asset_maintenance_report' => 'Laporan Penyenggaraan Aset',
    'asset_maintenances'       => 'Pembaikan Aset',
    'item'  				=> 'Perkara',
    'insufficient_permissions' => 'Kebenaran yang tidak mencukupi!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Bahasa',
    'last'					=> 'Terakhir',
    'last_login'            => 'Log masuk kali terakhir',
    'last_name'             => 'Nama Keluarga',
    'license'				=> 'Lesen',
    'license_report'        => 'Laporan Lesen',
    'licenses_available'	=> 'Lesen Yang Ada',
    'licenses'				=> 'Lesen',
    'list_all'				=> 'Senaraikan Semua',
    'loading'				=> 'Memuatkan',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Ciri ini telah dilumpuhkan untuk pemasangan demo.',
    'location'              => 'Lokasi',
    'locations'				=> 'Lokasi',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Log keluar',
    'lookup_by_tag'     => 'Cari dengan Tag Aset',
    'maintenances'          => 'Penyelenggaraan',
    'manufacturer'			=> 'Pengeluar',
    'manufacturers'			=> 'Pengeluar',
    'markdown'				=> 'Bidang ini membolehkan markah rasa <a href="https://help.github.com/articles/github-flavored-markdown/">Github</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'	=> 'Jumlah minimum item yang perlu disediakan sebelum amaran akan dicetuskan.',
    'model_no'				=> 'No. Model.',
    'months'				=> 'Bulan',
    'moreinfo'				=> 'Maklumat tambahan',
    'name'					=> 'Nama',
    'next'					=> 'Seterusnya',
    'next_audit_date'		=> 'Tarikh Audit Seterusnya',
    'last_audit'		    => 'Audit lepas',
    'new'					=> 'baru!',
    'no_depreciation'		=> 'Tiada Susut Nilai',
    'no_results'			=> 'Tiada kepututsan.',
    'no'  					=> 'Tidak',
    'notes'  				=> 'Nota',
    'order_number'          => 'Nombor Pesanan',
    'page_menu'				=> 'Menunjukkan _MENU_ item',
    'pagination_info'		=> 'Menunjukkan _START_ ke _END_ dari _TOTAL_ item',
    'pending'				=> 'Belum selesai',
    'people'				=> 'Orang',
    'per_page'				=> 'Senarai Setiap Mukasurat',
    'previous'				=> 'Sebelum ini',
    'processing'			=> 'Pemprosesan',
    'profile'				=> 'Profail Anda',
    'purchase_cost'                              => 'Kos Pembelian',
    'purchase_date'         => 'Tarikh Pembelian',
    'qty'		            => 'QTY',
    'quantity'		        => 'Kuantiti',
    'ready_to_deploy'		=> 'Sedia untuk diagihkan',
    'recent_activity'		=> 'Aktiviti Terkini',
    'remove_company'        => 'Keluarkan Persatuan Syarikat',
    'reports'				=> 'Laporan',
    'restored'				=> 'restored',
    'requested'				=> 'Diminta',
    'request_canceled'      => 'Permintaan Dibatalkan',
    'save'  				=> 'Simpan',
    'select'				=> 'Pilih',
    'search'				=> 'Carian',
    'select_category'       => 'Pilih kategori',
    'select_department'       => 'Pilih Jabatan',
    'select_depreciation'	=> 'Pilih Jenis Susutnilai',
    'select_location'		=> 'Pilih Lokasi',
    'select_manufacturer'	=> 'Pilih pengilang',
    'select_model'			=> 'Pilih Model',
    'select_supplier'		=> 'Pilih Pembekal',
    'select_user'			=> 'Pilih Pengguna',
    'select_date'			=> 'Pilih Tarikh (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Pilih Status',
    'select_company'    	=> 'Pilih Syarikat',
    'select_asset'    		=> 'Pilih Asset',
    'settings'				=> 'Tetapan',
    'show_deleted'  		=> 'Papar Dihapuskan',
    'show_current'  		=> 'Papar Semasa',
    'sign_in'				=> 'Log masuk',
    'signature'             => 'Tandatangan',
    'skin'       			=> 'Kulit',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'MODEM DEMO: Sesetengah ciri dilumpuhkan untuk pemasangan ini.',
    'site_name'				=> 'Nama Sesawang',
    'state'  				=> 'Negeri',
    'status_labels'			=> 'Label Status',
    'status'    			=> 'Status',
    'supplier'              => 'Pembekal',
    'suppliers'  			=> 'Pembekal',
    'sure_to_delete'    => 'Adakah anda pasti ingin memadamkannya',
    'submit'				=> 'Hantar',
    'target'                => 'Sasaran',
    'time_and_date_display' => 'Paparan Masa dan Tarikh',
    'total_assets'			=> 'jumlah harta',
    'total_licenses'		=> 'jumlah lesen',
    'total_accessories'		=> 'jumlah aksesori',
    'total_consumables'		=> 'jumlah barang habis',
    'type'  				=> 'Taipkan',
    'undeployable'			=> 'Tidak Boleh Agih',
    'unknown_admin'			=> 'Pentadbir Tidak Dikenali',
    'username_format'		=> 'Format Nama Pengguna',
    'update'                => 'Kemas kini',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Dimuat naik',
    'user'					=> 'Pengguna',
    'accepted'			    => 'diterima',
    'declined'			    => 'menurun',
    'unaccepted_asset_report' => 'Aset Tidak Diterima',
    'users'                 => 'Pengguna',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Paparkan Harta yang diserahkan',
    'website'               => 'Tapak web',
    'welcome'				=> 'Selamat Datang :nama',
    'years'					=> 'tahun',
    'yes' 					=> 'Ya',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Tiada gambar yang dimuat naik atau imej tidak dijumpai.',
    'token_expired'         => 'Sesi borang anda telah tamat tempoh. Sila cuba lagi.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ms/general.php <==
<?php

    return [
    'accessories'			=> 'Aksesori',
    'activated'			    => 'Diaktifkan',
    'accessory'				=> 'Aksesori',
    'accessory_report'		=> 'Laporan Aksesori',
    'action'                => 'Tindakan',
    'activity_report'		=> 'Laporan Aktiviti',
    'address'				=> 'Alamat',
    'admin'					=> 'Pentadbir',
    'administrator'			=> 'Pentadbir',
    'add_seats'             => 'Menambah kerusi',
    'all_assets'			=> 'Semua Harta',
    'all'       			=> 'Semua',
    'archived'              => 'Diarkibkan',
    'asset_models'			=> 'Model Harta',
    'asset_model'			=> 'Model',
    'asset'					=> 'Harta',
    'asset_report'          => 'Laporan Harta',
    'asset_tag'				=> 'Tag Harta',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Log Audit',
    'assets'				=> 'Harta',
    'avatar_delete'         => 'Hapuskan Avatar',
    'avatar_upload'         => 'Muat naik Avatar',
    'back'      			=> 'Belakang',
    'bad_data'      		=> 'Tiada apa-apa Dijumpai. Mungkin data buruk?',
    'bulkaudit'             => 'Audit Bulk',
    'bulkaudit_status'      => 'Status Audit',
    'bulk_checkout'  		=> 'Checkout Pukal',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Batalkan',
    'categories'			=> 'Kategori',
    'category'				=> 'Kategori',
    'change' 		        => 'Dalam keluar',
    'changeemail'  			=> 'Ubah Alamat E-mail',
    'changepassword'  		=> 'Tukar kata laluan',
    'checkin'  				=> 'Terima',
    'checkin_from'  		=> 'Semak dari',
    'checkout'  			=> 'Agihkan',
    'checkouts_count'       => 'Semak Keluar',
    'checkins_count'        => 'Semak masuk',
    'user_requests_count'   => 'Permintaan',
    'city'  				=> 'Bandar',
    'click_here'			=> 'Tekan di sini',
    'clear_selection'		=> 'Buang pilihan',
    'companies'			    => 'Syarikat-syarikat',
    'company'				=> 'Syarikat',
    'component'			    => 'Komponen',
    'components'			=> 'Komponen',
    'complete'				=> 'Lengkap',
    'consumable'			=> 'Boleh makan',
    'consumables'			=> 'Makanan yang boleh dimakan',
    'country'  				=> 'Negara',
    'create'				=> 'Cipta Baru',
    'created'               => 'Perkara yang Dibuat',
    'created_asset'			=> 'cipta harta',
    'created_at' 			=> 'Cipta Pada',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Dikemaskini di',
    'currency'  			=> 'RM', // this is deprecated
    'current'  				=> 'Semasa',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Laporan Harta Pilihan',
    'dashboard'				=> 'Papan Pemuka',
    'days'      			=> 'hari',
    'days_to_next_audit'    => 'Hari ke Audit Seterusnya',
    'date'					=> 'Tarikh',
    'debug_warning'         => 'Amaran!',
    'debug_warning_text'    => 'Aplikasi ini berjalan dalam mod pengeluaran dengan debug membolehkan. Ini boleh mendedahkan data sensitif jika aplikasi anda boleh diakses oleh dunia luar. Lumpuhkan mod debug dengan menetapkan <code>APP_DEBUG</code> nilai dalam fail <code>.env</code> anda ke <code>false</code>.',
    'delete'  				=> 'Hapuskan',
    'delete_confirm'  		=> 'Adakah anda pasti ingin memadamkan :item?',
    'deleted'  				=> 'Dihapuskan',
    'delete_seats'  		=> 'Kerusi dipadamkan',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'Jabatan',
    'department'            => 'Jabatan',
    'deployed'				=> 'Telah Diagihkan',
    'depreciation'			=> 'Susut Nilai',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Laporan Susut nilai',
    'details'               => 'Terperinci',
    'download'				=> 'Muat turun',
    'download_all'		    => 'Download All',
    'editprofile'  			=> 'Kemaskini Profail Anda',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Domain E-mel',
    'email_format'			=> 'Format E-mel',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Ini digunakan untuk menjana alamat e-mel semasa mengimport',
    'error'				    => 'Error',
    'filastname_format'			=> 'Nama Akhir Permulaan Pertama (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nama Akhir Nama Pertama (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Nama Pertama Nama Akhir (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Pertama',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Nama pertama',
    'first_name_format'		=> 'Nama Pertama (jane@example.com)',
    'files'                 => 'Fail-fail',
    'file_name'				=> 'Fail',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Muat Naik Fail',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Laksanakan',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Kumpulan',
    'gravatar_email'        => 'Alam e-mel gravatar',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Sejarah',
    'history_for'  			=> 'Sejarah untuk',
    'id'  					=> 'ID',
    'image'                 => 'Gambar',
    'image_delete'         	=> 'Hapuskan imej',
    'image_upload'         	=> 'Muat naik imej',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Sejarah Import',
    'asset_maintenance'        => 'Penyelenggaraan Aset',
    'asset_maintenance_report' => 'Laporan Penyenggaraan Aset',
    'asset_maintenances'       => 'Pembaikan Aset',
    'item'  				=> 'Perkara',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Kebenaran yang tidak mencukupi!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Bahasa',
    'last'					=> 'Terakhir',
    'last_login'            => 'Log masuk kali terakhir',
    'last_name'             => 'Nama Keluarga',
    'license'				=> 'Lesen',
    'license_report'        => 'Laporan Lesen',
    'licenses_available'	=> 'Lesen Yang Ada',
    'licenses'				=> 'Lesen',
    'list_all'				=> 'Senaraikan Semua',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Ciri ini telah dilumpuhkan untuk pemasangan demo.',
    'location'              => 'Lokasi',
    'locations'				=> 'Lokasi',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Log keluar',
    'lookup_by_tag'     => 'Cari dengan Tag Aset',
    'maintenances'          => 'Penyelenggaraan',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Pengeluar',
    'manufacturers'			=> 'Pengeluar',
    'markdown'				=> 'Bidang ini membolehkan markah rasa <a href="https://help.github.com/articles/github-flavored-markdown/">Github</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'No. Model.',
    'months'				=> 'Bulan',
    'moreinfo'				=> 'Maklumat tambahan',
    'name'					=> 'Nama',
    'new_password'          => 'New Password',
    'next'					=> 'Seterusnya',
    'next_audit_date'		=> 'Tarikh Audit Seterusnya',
    'last_audit'		    => 'Audit lepas',
    'new'					=> 'baru!',
    'no_depreciation'		=> 'Tiada Susut Nilai',
    'no_results'			=> 'Tiada kepututsan.',
    'no'  					=> 'Tidak',
    'notes'  				=> 'Nota',
    'order_number'          => 'Nombor Pesanan',
    'page_menu'				=> 'Menunjukkan _MENU_ item',
    'pagination_info'		=> 'Menunjukkan _START_ ke _END_ dari _TOTAL_ item',
    'pending'				=> 'Belum selesai',
    'people'				=> 'Orang',
    'per_page'				=> 'Senarai Setiap Mukasurat',
    'previous'				=> 'Sebelum ini',
    'processing'			=> 'Pemprosesan',
    'profile'				=> 'Profail Anda',
    'purchase_cost'                              => 'Kos Pembelian',
    'purchase_date'         => 'Tarikh Pembelian',
    'qty'		            => 'QTY',
    'quantity'		        => 'Kuantiti',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Sedia untuk diagihkan',
    'recent_activity'		=> 'Aktiviti Terkini',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Keluarkan Persatuan Syarikat',
    'reports'				=> 'Laporan',
    'restored'				=> 'restored',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Diminta',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Permintaan Dibatalkan',
    'save'  				=> 'Simpan',
    'select'				=> 'Pilih',
    'select_all'            => 'Select All',
    'search'				=> 'Carian',
    'select_category'       => 'Pilih kategori',
    'select_department'     => 'Pilih Jabatan',
    'select_depreciation'	=> 'Pilih Jenis Susutnilai',
    'select_location'		=> 'Pilih Lokasi',
    'select_manufacturer'	=> 'Pilih pengilang',
    'select_model'			=> 'Pilih Model',
    'select_supplier'		=> 'Pilih Pembekal',
    'select_user'			=> 'Pilih Pengguna',
    'select_date'			=> 'Pilih Tarikh (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Pilih Status',
    'select_company'    	=> 'Pilih Syarikat',
    'select_asset'    		=> 'Pilih Asset',
    'settings'				=> 'Tetapan',
    'show_deleted'  		=> 'Papar Dihapuskan',
    'show_current'  		=> 'Papar Semasa',
    'sign_in'				=> 'Log masuk',
    'signature'             => 'Tandatangan',
    'skin'       			=> 'Kulit',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'MODEM DEMO: Sesetengah ciri dilumpuhkan untuk pemasangan ini.',
    'site_name'				=> 'Nama Sesawang',
    'state'  				=> 'Negeri',
    'status_labels'			=> 'Label Status',
    'status'    			=> 'Status',
    'supplier'              => 'Pembekal',
    'suppliers'  			=> 'Pembekal',
    'sure_to_delete'    => 'Adakah anda pasti ingin memadamkannya',
    'submit'				=> 'Hantar',
    'target'                => 'Sasaran',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Paparan Masa dan Tarikh',
    'total_assets'			=> 'jumlah harta',
    'total_licenses'		=> 'jumlah lesen',
    'total_accessories'		=> 'jumlah aksesori',
    'total_consumables'		=> 'jumlah barang habis',
    'type'  				=> 'Taipkan',
    'undeployable'			=> 'Tidak Boleh Agih',
    'unknown_admin'			=> 'Pentadbir Tidak Dikenali',
    'username_format'		=> 'Format Nama Pengguna',
    'update'                => 'Kemas kini',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Dimuat naik',
    'user'					=> 'Pengguna',
    'accepted'			    => 'diterima',
    'declined'			    => 'menurun',
    'unaccepted_asset_report' => 'Aset Tidak Diterima',
    'users'                 => 'Pengguna',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Paparkan Harta yang diserahkan',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Tapak web',
    'welcome'				=> 'Selamat Datang :nama',
    'years'					=> 'tahun',
    'yes' 					=> 'Ya',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Tiada gambar yang dimuat naik atau imej tidak dijumpai.',
    'token_expired'         => 'Sesi borang anda telah tamat tempoh. Sila cuba lagi.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
